@@ -2,7 +2,7 @@ package Astro::Catalog::IO::JCMT;
 
 =head1 NAME
 
-Astro::Catalog::IO::JCMT - JCMT catalogue I/O for Astro::Catalog
+Astro::Catalog::IO::JCMT - JCMT catalog I/O for Astro::Catalog
 
 =head1 SYNOPSIS
 
@@ -12,8 +12,8 @@ Astro::Catalog::IO::JCMT - JCMT catalogue I/O for Astro::Catalog
 
 =head1 DESCRIPTION
 
-This class provides read and write methods for catalogues in the JCMT
-pointing catalogue format. The methods are not public and should, in general,
+This class provides read and write methods for catalogs in the JCMT
+pointing catalog format. The methods are not public and should, in general,
 only be called from the C<Astro::Catalog> C<write_catalog> and C<read_catalog>
 methods.
 
@@ -31,7 +31,7 @@ use Astro::Catalog::Item;
 
 use base qw/Astro::Catalog::IO::ASCII/;
 
-our $VERSION = '4.36';
+our $VERSION = '4.37';
 our $DEBUG   = 0;
 
 # Name must be limited to 15 characters on write
@@ -40,7 +40,7 @@ use constant MAX_SRC_LENGTH => 15;
 # Default location for a JCMT catalog
 my $defaultCatalog = "/local/progs/etc/poi.dat";
 
-# Planets appended to the catalogue
+# Planets appended to the catalog
 my @PLANETS = qw/mercury mars uranus saturn jupiter venus neptune/;
 
 =over 4
@@ -51,9 +51,9 @@ Method to take a general target name and clean it up
 so that it is suitable for writing in a JCMT source catalog.
 This routine is used by the catalog writing code but can also
 be used publically in order to make sure that a target name
-to be written to the catalogue is guaranteed to match that used
+to be written to the catalog is guaranteed to match that used
 in another location (e.g. when writing an a document to accompany
-the catalogue which refers to targets within it).
+the catalog which refers to targets within it).
 
 The source name can be truncated.
 
@@ -89,9 +89,9 @@ sub clean_target_name {
 
 =item B<_default_file>
 
-Returns the location of the default JCMT pointing catalogue at the
+Returns the location of the default JCMT pointing catalog at the
 JCMT itself. This is purely for convenience of the caller when they
-are at the JCMT and wish to use the default catalogue without having
+are at the JCMT and wish to use the default catalog without having
 to know explicitly where it is.
 
     $filename = Astro::Catalog::IO::JCMT->_default_file();
@@ -112,7 +112,7 @@ sub _default_file {
 
 =item B<_read_catalog>
 
-Parses the catalogue lines and returns a new C<Astro::Catalog>
+Parses the catalog lines and returns a new C<Astro::Catalog>
 object containing the catalog entries.
 
     $cat = Astro::Catalog::IO::JCMT->_read_catalog(\@lines, %options);
@@ -123,7 +123,9 @@ Supported options (with defaults) are:
                  (defaults to JCMT). If the telescope option is specified
                  but is undef or empty string, no telescope is used.
 
-    incplanets => Append planets to catalogue entries (default is true)
+    incplanets => Append planets to catalog entries (default is true)
+
+    inccomments => Read comment lines into misc entries (default: false)
 
 =cut
 
@@ -134,11 +136,14 @@ sub _read_catalog {
     # Default options
     my %defaults = (
         telescope => 'JCMT',
-        incplanets => 1);
+        incplanets => 1,
+        inccomments => 0,
+        respacecomments => 1,
+    );
 
     my %options = (%defaults, @_);
 
-    croak "Must supply catalogue contents as a reference to an array"
+    croak "Must supply catalog contents as a reference to an array"
         unless ref($lines) eq 'ARRAY';
 
     # Create a new telescope to associate with this
@@ -148,7 +153,13 @@ sub _read_catalog {
 
     # Go through each line and parse it
     # and store in the array if we had a successful read
-    my @stars = map {$class->_parse_line($_, $tel);} @$lines;
+    my $parse_buff = $options{'inccomments'} ? {} : undef;
+    my @stars = map {$class->_parse_line($_, $tel, $parse_buff, \%options);} @$lines;
+
+    $stars[-1]->misc->{'_jcmt_com_after'} = delete $parse_buff->{'comments'}
+        if ((defined $parse_buff)
+            and (scalar @stars)
+            and (exists $parse_buff->{'comments'}));
 
     # Add planets if required
     if ($options{incplanets}) {
@@ -183,17 +194,40 @@ sub _read_catalog {
 Write the catalog to an array and return it. Returning a reference to
 an array provides more flexibility to the caller.
 
-    $ref = Astro::Catalog::IO::JCMT->_write_catalog($cat);
+    $ref = Astro::Catalog::IO::JCMT->_write_catalog($cat, %options);
 
 Spaces are removed from source names. The contents of the catalog
 are sanity checked.
 
+Supported options (with defaults) are:
+
+=over 4
+
+=item incheader
+
+Add a comment header to the start of the catalog.  [default: true]
+
+=item removeduplicates
+
+Check for duplicates.  Remove if the coordinates match.  Add suffix
+to disambiguate otherwise.  [default: true]
+
+=back
+
 =cut
 
 sub _write_catalog {
     my $class = shift;
     my $cat = shift;
 
+    # Default options
+    my %defaults = (
+        incheader => 1,
+        removeduplicates => 1,
+    );
+
+    my %options = (%defaults, @_);
+
     # Would make more sense to use the array ref here
     my @sources = $cat->stars;
 
@@ -239,6 +273,11 @@ sub _write_catalog {
         $srcdata{vdefn}  = 'RADIO';
         $srcdata{vframe} = 'LSR';
 
+        # Default proper motion and parallax.
+        $srcdata{'pm1'} = 'n/a';
+        $srcdata{'pm2'} = 'n/a';
+        $srcdata{'parallax'} = 'n/a';
+
         # Get the miscellaneous data.
         my $misc = $star->misc;
         if (defined $misc) {
@@ -254,14 +293,18 @@ sub _write_catalog {
             $srcdata{flux850} = "n/a";
         }
 
+        foreach (qw/_jcmt_com_before _jcmt_com_after/) {
+            $srcdata{$_} = $misc->{$_} if exists $misc->{$_};
+        }
+
         # Get the type of source
         my $type = $src->type;
         if ($type eq 'RADEC') {
             $srcdata{system} = "RJ";
 
             # Need to get the space separated RA/Dec and the sign
-            $srcdata{long} = $src->ra(format => 'array');
-            $srcdata{lat} = $src->dec(format => 'array');
+            $srcdata{long} = $src->ra2000(format => 'array');
+            $srcdata{lat} = $src->dec2000(format => 'array');
 
             # Get the velocity information
             my $rv = $src->rv;
@@ -275,6 +318,20 @@ sub _write_catalog {
 
             }
 
+            my $parallax = $src->parallax;
+            my @pm = $src->pm;
+            if (scalar @pm) {
+                if (not $parallax) {
+                    my $errname = (defined $srcdata{name} ? $srcdata{name} : "<undefined>");
+                    warnings::warnif "Proper motion for target $errname specified without parallax";
+                }
+                $srcdata{'pm1'} = $pm[0] * 1000.0;
+                $srcdata{'pm2'} = $pm[1] * 1000.0;
+            }
+            if ($parallax) {
+                $srcdata{'parallax'} = $parallax * 1000.0;
+            }
+
         }
         elsif ($type eq 'PLANET') {
             # Planets are not supported in catalog form. Skip them
@@ -307,14 +364,14 @@ sub _write_catalog {
         # See if we already have this source and that it is really the
         # same source Note that we do not see whether this name is the
         # same as one of the derived names. Eg if CRL618 is in the
-        # pointing catalogue 3 times with identical coords and we add a
+        # pointing catalog 3 times with identical coords and we add a
         # new CRL618 with different coords then we trigger 3 warning
         # messages rather than 1 because we do not check that CRL618_2 is
         # the same as CRL618_1
 
         # Note that velocity specification is included in this comparison
 
-        if (exists $targets{$srcdata{name}}) {
+        if ($options{'removeduplicates'} and exists $targets{$srcdata{name}}) {
             my $previous = $targets{$srcdata{name}};
 
             # Create stringified form of previous coordinate with same name
@@ -328,10 +385,7 @@ sub _write_catalog {
                 # This is the same target so we can ignore it
             }
             else {
-                # Make up a new name. Use the unknown counter for this since
-                # we probably have not used it before. Probably not the best
-                # approach and might have problems in edge cases but good
-                # enough for now
+                # Make up a new name. Use a counter for this.
                 my $oldname = $srcdata{name};
 
                 # loop for 100 times
@@ -340,19 +394,14 @@ sub _write_catalog {
                     # protection loop
                     $count++;
 
-                    # Try to construct a new name based on a global counter
-                    # rather than a counter that starts at 1 for each root
-                    my $suffix = "_$unk";
-
-                    # increment $unk for next try
-                    $unk++;
+                    # Try to construct a new name based on the counter.
+                    my $suffix = "_$count";
 
                     # Abort if we have gone round too many times
-                    # Making sure that $unk is incremented first
                     if ($count > 100) {
                         $srcdata{name} = substr($oldname, 0, int(MAX_SRC_LENGTH / 2)) .
                             int(rand(10000) + 1000);
-                        warn "Uncontrollable looping (or unfeasibly large number of duplicate sources with different coordinates). Panicked and generated random source name of $srcdata{name}.\n";
+                        warn "Uncontrollable looping (or unfeasibly large number of duplicate sources with different coordinates). Panicked and generated random source name of $srcdata{name}\n";
                         last;
                     }
 
@@ -373,15 +422,15 @@ sub _write_catalog {
                     my $newname = $root . $suffix;
 
                     # check to see if this name is in the existing target list
-                    next if exists $allnames{$newname};
-
-                    # Store it in the targets array and exit loop
-                    $srcdata{name} = $newname;
-                    last;
+                    unless ((exists $allnames{$newname}) or (exists $targets{$newname})) {
+                        # Store it in the targets array and exit loop
+                        $srcdata{name} = $newname;
+                        last;
+                    }
                 }
 
                 # different target
-                warn "Found target with the same name [$oldname] but with different coordinates, renaming it to $srcdata{name}!\n";
+                warn "Found target with the same name [$oldname] but with different coordinates, renaming it to $srcdata{name}\n";
 
                 $targets{$srcdata{name}} = \%srcdata;
 
@@ -401,15 +450,21 @@ sub _write_catalog {
     # Output array for new catalog lines
     my @lines;
 
-    # Write a header
-    push @lines, "*\n";
-    push @lines, "* Catalog written automatically by class ". __PACKAGE__ ."\n";
-    push @lines, "* on date " . gmtime . "UT\n";
-    push @lines, "* Origin of catalogue: ". $cat->origin ."\n";
-    push @lines, "*\n";
+    if ($options{'incheader'}) {
+        # Write a header
+        push @lines, "*\n";
+        push @lines, "* Catalog written automatically by class ". __PACKAGE__ ."\n";
+        push @lines, "* on date " . gmtime . "UT\n";
+        push @lines, "* Origin of catalog: ". $cat->origin ."\n";
+        push @lines, "*\n";
+    }
 
     # Now need to go through the targets and write them to disk
     for my $src (@processed) {
+        if (exists $src->{'_jcmt_com_before'}) {
+            push @lines, '*' . $_ foreach @{$src->{'_jcmt_com_before'}};
+        }
+
         my $name    = $src->{name};
         my $long    = $src->{long};
         my $lat     = $src->{lat};
@@ -420,48 +475,84 @@ sub _write_catalog {
         my $vframe  = $src->{vframe};
         my $vrange  = $src->{vrange};
         my $flux850 = $src->{flux850};
+        my $pm1     = $src->{'pm1'};
+        my $pm2     = $src->{'pm2'};
+        my $px      = $src->{'parallax'};
 
         $comment = '' unless defined $comment;
 
         # Velocity can not easily be done with a sprintf since it can be either
         # a string or a 2 column number
-        if (lc($rv) eq 'n/a') {
-            $rv = '  n/a   ';
-        }
-        else {
-            my $sign = ($rv >= 0 ? '+' : '-');
-            my $val  = $rv;
-            $val =~ s/^\s*[+-]\s*//;
-            $val =~ s/\s*$//;
-            $rv = $sign . ' ' . sprintf('%6.1f',$val);
-        }
+        $rv  = _format_value($rv, '%6.1f', '  n/a   ', 1);
+
+        # Similarly format proper motion and parallax.
+        $pm1 = _format_value($pm1, '%8.3f', '   n/a    ', 1);
+        $pm2 = _format_value($pm2, '%8.3f', '   n/a    ', 1);
+        $px  = _format_value($px,  '%8.4f', '  n/a   ', 0);
 
         # Name must be limited to MAX_SRC_LENGTH characters
         # [this should be taken care of by clean_target_name but
         # if we have appended _X....
         $name = substr($name,0,MAX_SRC_LENGTH);
 
+        # Maybe shift flux by 1 space to align decimal point in
+        # 1dp values with that in 2dp values and also middle of n/a.
+        $flux850 .= ' ' if $flux850 =~ /(?:\.\d|n\/a)$/ and 5 > length $flux850;
+
         push @lines, sprintf(
-            "%-" . MAX_SRC_LENGTH .  "s %02d %02d %06.3f %1s %02d %02d %05.2f %2s  %s %5s  %5s  %-4s %s %s\n",
-            $name, @$long, @$lat, $system, $rv, $flux850, $vrange, $vframe, $vdefn, $comment);
+            "%-" . MAX_SRC_LENGTH .  "s %02d %02d %06.3f %1s %02d %02d %05.2f %2s  %s %5s  %5s  %-4s %s %s %s %s %s\n",
+            $name, @$long, @$lat, $system,
+            $rv, $flux850, $vrange, $vframe, $vdefn,
+            $pm1, $pm2, $px,
+            $comment);
+
+        if (exists $src->{'_jcmt_com_after'}) {
+            push @lines, '*' . $_ foreach @{$src->{'_jcmt_com_after'}};
+        }
     }
 
     return \@lines;
 }
 
+=item B<_format_value>
+
+Format a value for inclusion in a JCMT format catalog.
+
+=cut
+
+sub _format_value {
+    my ($val, $fmt, $na, $signed) = @_;
+
+    if (lc($val) eq 'n/a') {
+        return $na;
+    }
+
+    my $sign = ($val >= 0 ? '+' : '-');
+    $val =~ s/^\s*[+-]\s*//;
+    $val =~ s/\s*$//;
+    unless ($signed) {
+        warnings::warnif "Unsigned value is negative" unless $sign eq '+';
+        return sprintf($fmt, $val);
+    }
+    return $sign . ' ' . sprintf($fmt, $val);
+}
+
 =item B<_parse_line>
 
-Parse a line from a JCMT format catalogue and return a corresponding
+Parse a line from a JCMT format catalog and return a corresponding
 C<Astro::Catalog::Item> object. Returns empty list if the line can not
 be parsed or refers to a comment line (so that map can be used in the
 caller).
 
-    $star = Astro::Catalog::IO::JCMT->_parse_line($line, $tel);
+    $star = Astro::Catalog::IO::JCMT->_parse_line($line, $tel, \%status_buffer, \%options);
 
 where C<$line> is the line to be parsed and (optional) C<$tel>
 is an C<Astro::Telescope> object to be associated with the
 coordinate objects.
 
+A reference to a hash can be provided to track parsing status between lines.
+This is currently used to store comments read from the catalog.
+
 The line is parsed using a pattern match.
 
 =cut
@@ -470,11 +561,16 @@ sub _parse_line {
     my $class = shift;
     my $line = shift;
     my $tel = shift;
+    my $parse_buff = shift;
+    my $options = shift;
     chomp $line;
 
     # Skip commented and blank lines
-    return if ($line =~ /^\s*[\*\%]/);
     return if ($line =~ /^\s*$/);
+    if ($line =~ s/^\s*[\*\%]//) {
+        push @{$parse_buff->{'comments'}}, $line if $parse_buff;
+        return;
+    }
 
     # Use a pattern match parser
     my @match = ($line =~ m/
@@ -508,7 +604,13 @@ sub _parse_line {
         \s*
         ([\w\/]+)?               # vel defn [12]
         \s*
-        (.*)$                    # comment [13]
+        (n\/a|[+-]\s*\d+(?:\.\d*)?)?  # pm1 [13]
+        \s*
+        (n\/a|[+-]\s*\d+(?:\.\d*)?)?  # pm2 [14]
+        \s*
+        (n\/a|\d+(?:\.\d*)?)?    # parallax [15]
+        \s*
+        (.*)$                    # comment [16]
         /xi);
 
     # Abort if we do not have matches for the first 8 fields
@@ -555,11 +657,11 @@ sub _parse_line {
     }
 
     # catalog comments are space delimited
-    my $ccol = 13;
+    my $ccol = 16;
     my $cat_comm = (defined $match[$ccol] ? $match[$ccol] : '');
 
     # Replace multiple spaces in comment with single space
-    $cat_comm =~ s/\s+/ /g;
+    $cat_comm =~ s/\s+/ /g if $options->{'respacecomments'};
 
     # velocity
     $coords{vdefn} = "RADIO";
@@ -571,6 +673,19 @@ sub _parse_line {
         $coords{vframe} = $match[11];
     }
 
+    if ((defined $match[13]) and (defined $match[14])
+            and ($match[13] !~ /n/) and ($match[14] !~ /n/)) {
+        $match[13] =~ s/\s//g; # remove spaces
+        $match[14] =~ s/\s//g; # remove spaces
+        # Convert components of proper motion from mas/year to arcsec/year.
+        $coords{'pm'} = [$match[13] / 1000.0, $match[14] / 1000.0];
+    }
+
+    if ((defined $match[15]) and ($match[15] !~ /n/)) {
+        # Convert parallax from mas to arcsec.
+        $coords{'parallax'} = $match[15] / 1000.0;
+    }
+
     # create the source object
     my $source = new Astro::Coords(%coords);
 
@@ -601,6 +716,9 @@ sub _parse_line {
         $misc{'flux850'} = $match[9];
     }
 
+    $misc{'_jcmt_com_before'} = delete $parse_buff->{'comments'}
+        if exists $parse_buff->{'comments'};
+
     print "Created a new source in _parse_line: $target in field $field\n" if $DEBUG;
 
     # Now create the star object
@@ -645,7 +763,7 @@ The following constants are available for querying:
 
 =item MAX_SRC_LENGTH
 
-The maximum length of sourcenames writable to a JCMT source catalogue.
+The maximum length of sourcenames writable to a JCMT source catalog.
 
 =back
 
